@@ -97,13 +97,13 @@ class test_spliter(unittest.TestCase):
     # @unittest.skip('ignore')
     def test_short(self):
         sentence = '1234567890.1234567890。'
-        out = spliter.cut_to_sentences(sentence, long_short=True)
+        out = spliter.cut_to_sentences(sentence)
         expect = ['1234567890.1234567890。']
         self.assertEqual(expect, out)
 
         sentence = '123。12354657789。 12324354364。'
-        out = spliter.cut_to_sentences(sentence, long_short=True)
-        expect = ['123。12354657789。', ' 12324354364。']
+        out = spliter.cut_to_sentences(sentence)
+        expect = ['123。','12354657789。', ' 12324354364。']
         self.assertEqual(expect, out)
 
     def test_says(self):
@@ -117,7 +117,8 @@ class test_spliter(unittest.TestCase):
         out = spliter.cut_to_sentences(sentence)
         expect = []
         self.assertEqual(expect, out)
-
+    def test_long(self):
+        de
 
 if __name__ == '__main__':
     unittest.main()
